summaryrefslogtreecommitdiffstats
path: root/kwin-styles/icewm/config/config.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-11-07 20:25:05 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-11-07 20:25:05 -0600
commita5355f151396be579eba5838c7d8d93a43362cd7 (patch)
tree4660e8f56be211f2b4128e1591efc3dcfc0cf850 /kwin-styles/icewm/config/config.cpp
parent430baee366780c4f1eb2143a088590b91a957800 (diff)
downloadtdeartwork-a5355f151396be579eba5838c7d8d93a43362cd7.tar.gz
tdeartwork-a5355f151396be579eba5838c7d8d93a43362cd7.zip
Rename kwin to twin (part 1 of 2)
Diffstat (limited to 'kwin-styles/icewm/config/config.cpp')
-rw-r--r--kwin-styles/icewm/config/config.cpp22
1 files changed, 11 insertions, 11 deletions
diff --git a/kwin-styles/icewm/config/config.cpp b/kwin-styles/icewm/config/config.cpp
index 8b679d54..a0a2a8db 100644
--- a/kwin-styles/icewm/config/config.cpp
+++ b/kwin-styles/icewm/config/config.cpp
@@ -48,18 +48,18 @@ extern "C"
// NOTE:
// ==========================================================================
// 'conf' is a pointer to the kwindecoration modules open kwin config,
// and is by default set to the "Style" group.
//
// 'parent' is the parent of the TQObject, which is a VBox inside the
-// Configure tab in kwindecoration
+// Configure tab in twindecoration
// ==========================================================================
IceWMConfig::IceWMConfig( KConfig* conf, TQWidget* parent )
: TQObject( parent )
{
- icewmConfig = new KConfig("kwinicewmrc");
- KGlobal::locale()->insertCatalogue("kwin_art_clients");
+ icewmConfig = new KConfig("twinicewmrc");
+ KGlobal::locale()->insertCatalogue("twin_art_clients");
mainWidget = new TQVBox( parent );
mainWidget->setSpacing( KDialog::spacingHint() );
@@ -123,7 +123,7 @@ IceWMConfig::IceWMConfig( KConfig* conf, TQWidget* parent )
this, TQT_SLOT(slotSelectionChanged()) );
// Create the theme directory (if not found) ... and obtain the path as we do so.
- localThemeString = KGlobal::dirs()->saveLocation("data", "kwin");
+ localThemeString = KGlobal::dirs()->saveLocation("data", "twin");
localThemeString += "/icewm-themes";
if (!TQFile::exists(localThemeString))
TQDir().mkdir(localThemeString);
@@ -139,7 +139,7 @@ IceWMConfig::IceWMConfig( KConfig* conf, TQWidget* parent )
urlThemeString.replace( TQRegExp("~"), "$HOME" );
urlLabel->setURL( urlThemeString );
- // Make the widgets visible in kwindecoration
+ // Make the widgets visible in twindecoration
mainWidget->show();
KDirWatch::self()->startScan();
@@ -158,14 +158,14 @@ IceWMConfig::~IceWMConfig()
// Searches for all installed IceWM themes, and adds them to the listBox.
void IceWMConfig::findIceWMThemes()
{
- TQStringList dirList = KGlobal::dirs()->findDirs("data", "kwin/icewm-themes");
+ TQStringList dirList = KGlobal::dirs()->findDirs("data", "twin/icewm-themes");
TQStringList::ConstIterator it;
// Remove any old themes in the list (if any)
themeListBox->clear();
themeListBox->insertItem( i18n("Infadel #2 (default)") );
// Step through all kwin/icewm-themes directories...
for( it = dirList.begin(); it != dirList.end(); it++)
{
// List all directory names only...
@@ -175,7 +175,7 @@ void IceWMConfig::findIceWMThemes()
TQFileInfoListIterator it2( *d.entryInfoList() );
TQFileInfo* finfo;
// Step through all directories within the kwin/icewm-themes directory
while( (finfo = it2.current()) )
{
// Ignore . and .. directories
@@ -223,7 +223,7 @@ void IceWMConfig::slotSelectionChanged()
}
// Loads the configurable options from the kwinicewmrc config file
void IceWMConfig::load( KConfig* )
{
icewmConfig->setGroup("General");
@@ -241,7 +241,7 @@ void IceWMConfig::load( KConfig* )
}
// Saves the configurable options to the kwinicewmrc config file
void IceWMConfig::save( KConfig* )
{
icewmConfig->setGroup("General");
@@ -48,18 +48,18 @@ extern "C"
// NOTE:
// ==========================================================================
-// 'conf' is a pointer to the kwindecoration modules open kwin config,
+// 'conf' is a pointer to the twindecoration modules open twin config,
// and is by default set to the "Style" group.
//
@@ -158,14 +158,14 @@ IceWMConfig::~IceWMConfig()
themeListBox->clear();
themeListBox->insertItem( i18n("Infadel #2 (default)") );
- // Step through all kwin/icewm-themes directories...
+ // Step through all twin/icewm-themes directories...
for( it = dirList.begin(); it != dirList.end(); it++)
{
@@ -175,7 +175,7 @@ void IceWMConfig::findIceWMThemes()
TQFileInfoListIterator it2( *d.entryInfoList() );
TQFileInfo* finfo;
- // Step through all directories within the kwin/icewm-themes directory
+ // Step through all directories within the twin/icewm-themes directory
while( (finfo = it2.current()) )
{
@@ -223,7 +223,7 @@ void IceWMConfig::slotSelectionChanged()
}
-// Loads the configurable options from the kwinicewmrc config file
+// Loads the configurable options from the twinicewmrc config file
void IceWMConfig::load( KConfig* )
{
@@ -241,7 +241,7 @@ void IceWMConfig::load( KConfig* )
}
-// Saves the configurable options to the kwinicewmrc config file
+// Saves the configurable options to the twinicewmrc config file
void IceWMConfig::save( KConfig* )
{